@@ -1,5 +1,7 @@
 from ovos_skills_manager.exceptions import *
 from ovos_utils import camel_case_split
+
+
 from ovos_skills_manager.session import SESSION as requests
 from enum import Enum
 
@@ -94,6 +96,10 @@ def get_branch_from_github_url(url, validate=False):
     url = url.replace("/blob/", "/tree/")
     if "/tree/" in url:
         branch = url.split("/tree/")[-1].split("/")[0]
+    if "/commit/" in url:
+        branch = url.split("/commit/")[-1].split("/")[0]
+    if "/tag/" in url:
+        branch = url.split("/tag/")[-1].split("/")[0]
 
     if branch:
         if validate:
